@@ -1,15 +1,21 @@
 from matplotlib.axes import Axes
 from matplotlib.figure import Figure
 import matplotlib.pyplot as plt
-from numpy import array, ndarray
+from numpy import ndarray, reshape
 from pathlib import Path
-from typing import Tuple, Union, Dict, Callable, List
+from typing import Tuple, Union, Dict, Callable, List, Optional, TypeVar
 
 from mpl_format.axes.axes_formatter import AxesFormatter
 from mpl_format.axes.axes_formatter_array import AxesFormatterArray
 from mpl_format.io_utils import save_plot
 
 
+TextSetter = TypeVar(
+    'TextSetter',
+    str, List[str], Callable[[int, int], str], Callable[[int], str]
+)
+
+
 class FigureFormatter(object):
 
     share_values = ('all', 'row', 'col', 'none')
@@ -18,34 +24,45 @@ class FigureFormatter(object):
                  n_rows: int = 1, n_cols: int = 1,
                  fig_size: Tuple[int, int] = (16, 9),
                  share_x: str = 'none',
-                 share_y: str = 'none'):
+                 share_y: str = 'none',
+                 constrained_layout: bool = True):
 
         if fig_or_axes is not None:
             if isinstance(fig_or_axes, Figure):
                 self._figure = fig_or_axes
-                self._axes = fig_or_axes.axes
-                if isinstance(self._axes, list):
-                    self._axes = array(self._axes)
+                axes_list = self._figure.axes
+                rows_cols = (
+                    axes_list[0].get_subplotspec().get_topmost_subplotspec()
+                                .get_gridspec().get_geometry()
+                )
+                self._axes = reshape(axes_list, rows_cols)
             elif isinstance(fig_or_axes, Axes):
                 self._figure = fig_or_axes.figure
                 self._axes = fig_or_axes
             else:
-                raise ValueError('Can only instantiate a new FigureFormatter from an Axes or Figure instance.')
+                raise ValueError('Can only instantiate a new FigureFormatter '
+                                 'from an Axes or Figure instance.')
         else:
             assert share_x in self.share_values
             assert share_y in self.share_values
             self._fig_size: Tuple[int, int] = fig_size
-            figure, fig_or_axes = plt.subplots(nrows=n_rows, ncols=n_cols,
-                                               sharex=share_x, sharey=share_y,
-                                               figsize=fig_size)
-            self._axes: Union[Axes, ndarray] = fig_or_axes
+            figure, axes = plt.subplots(
+                nrows=n_rows, ncols=n_cols,
+                sharex=share_x, sharey=share_y,
+                figsize=fig_size,
+                constrained_layout=constrained_layout
+            )
+            self._axes: Union[Axes, ndarray] = axes
             self._figure: Figure = figure
-        self._has_array = isinstance(self._axes, ndarray) or isinstance(self._axes, list)
+        self._has_array = (
+                isinstance(self._axes, ndarray) or isinstance(self._axes, list)
+        )
 
     @property
     def axes(self) -> Union[AxesFormatter, AxesFormatterArray]:
         """
-        Return an AxesFormatter or AxesFormatterArray for the wrapped Axes or array of Axes.
+        Return an AxesFormatter or AxesFormatterArray for the wrapped Axes or
+        array of Axes.
         """
         if not self._has_array:
             return AxesFormatter(self._axes)
@@ -72,44 +89,129 @@ class FigureFormatter(object):
         else:
             raise TypeError('FigureFormatter holds a single Axes.')
 
-    def set_axes_title_text(
+    def _set_text_property(
             self,
-            text: Union[str, List[str], Callable[[int, int], str], Callable[[int], str]]
+            text: TextSetter,
+            method: Callable[[AxesFormatter, str], AxesFormatter]
     ) -> 'FigureFormatter':
         """
-        Set the title of each Axes using a string, list of strings or function that returns a string based on the
-        row and column or the flat index of the Axes.
+        Set a text property of each Axes using a string, list of strings,
+        or function that returns a string based on the row and column or the
+        flat index of the Axes.
 
         :param text: Title or titles to set
+        :param method: Method to call to format the text.
         """
         if not self._has_array:
             if not isinstance(text, str):
                 raise TypeError('text must be a str for a single Axes.')
             else:
-                self.single.set_title_text(text)
+                method(self.single, text)
         else:
             if isinstance(text, str):
                 for axf in self.multi.flat:
-                    axf.set_title_text(text)
+                    method(axf, text)
             elif isinstance(text, list):
                 if len(text) != self.multi.size:
-                    raise ValueError(f'There are {self.multi.size} Axes and {len(text)} labels.')
+                    raise ValueError(f'There are {self.multi.size} Axes'
+                                     f' and {len(text)} strings.')
                 else:
                     for axf, t in zip(self.multi.flat, text):
-                        axf.set_title_text(t)
+                        method(axf, t)
             elif callable(text):
                 try:
                     for row in range(self.multi.shape[0]):
                         for col in range(self.multi.shape[1]):
-                            self.multi[row, col].set_title_text(text(row, col))
+                            method(self.multi[row, col], text(row, col))
                 except TypeError:
                     for a, axf in enumerate(self.multi.flat):
-                        axf.set_title_text(text(a))
+                        method(axf, text(a))
             else:
-                raise TypeError(f'Wrong type passed to set_axes_title_text: {type(text)}')
+                raise TypeError(
+                    f'Wrong type passed to _set_text_property: {type(text)}'
+                )
         return self
 
-    def map_axes_title_text(self, mapping: Union[Dict[str, str], Callable[[str], str]]) -> 'FigureFormatter':
+    def set_axes_title_text(
+            self,
+            text: TextSetter
+    ) -> 'FigureFormatter':
+        """
+        Set the title text of each Axes using a string, list of strings,
+        or function that returns a string based on the row and column or the
+        flat index of the Axes.
+
+        :param text: Title or titles to set.
+        """
+        def set_text(
+                axes_formatter: AxesFormatter, string: str
+        ) -> AxesFormatter:
+            return axes_formatter.set_title_text(string)
+
+        self._set_text_property(text=text, method=set_text)
+        return self
+
+    def set_axes_x_label_text(
+            self,
+            text: TextSetter
+    ) -> 'FigureFormatter':
+        """
+        Set the x-label text of each Axes using a string, list of strings,
+        or function that returns a string based on the row and column or the
+        flat index of the Axes.
+
+        :param text: Label or labels to set.
+        """
+        def set_text(
+                axes_formatter: AxesFormatter, string: str
+        ) -> AxesFormatter:
+            return axes_formatter.set_x_label_text(string)
+
+        self._set_text_property(text=text, method=set_text)
+        return self
+
+    def set_axes_y_label_text(
+            self, text: TextSetter
+    ) -> 'FigureFormatter':
+        """
+        Set the x-label text of each Axes using a string, list of strings,
+        or function that returns a string based on the row and column or the
+        flat index of the Axes.
+
+        :param text: Label or labels to set.
+        """
+        def set_text(
+                axes_formatter: AxesFormatter, string: str
+        ) -> AxesFormatter:
+            return axes_formatter.set_y_label_text(string)
+
+        self._set_text_property(text=text, method=set_text)
+        return self
+
+    def set_axes_text(
+            self,
+            title: Optional[TextSetter] = None,
+            x_label: Optional[TextSetter] = None,
+            y_label: Optional[TextSetter] = None
+    ) -> 'FigureFormatter':
+        """
+        Set the text for each Axes' title, x_label or y_label.
+
+        :param title: Axes titles.
+        :param x_label: Axes x-labels.
+        :param y_label: Axes y-labels.
+        """
+        if title is not None:
+            self.set_axes_title_text(title)
+        if x_label is not None:
+            self.set_axes_x_label_text(x_label)
+        if y_label is not None:
+            self.set_axes_y_label_text(y_label)
+        return self
+
+    def map_axes_title_text(
+            self, mapping: Union[Dict[str, str], Callable[[str], str]]
+    ) -> 'FigureFormatter':
         """
         Map the label text for the x-axis using a dictionary or function.
 
@@ -152,9 +254,12 @@ class FigureFormatter(object):
         self.remove_y_axis_labels()
         return self
 
-    def map_x_axis_labels(self, mapping: Union[Dict[str, str], Callable[[str], str]]) -> 'FigureFormatter':
+    def map_x_axis_labels(
+            self, mapping: Union[Dict[str, str], Callable[[str], str]]
+    ) -> 'FigureFormatter':
         """
-        Map the label text for each x-axis in the Figure using a dictionary or function.
+        Map the label text for each x-axis in the Figure using a dictionary
+        or function.
 
         :param mapping: Dictionary or a function mapping old text to new text.
         """
@@ -165,9 +270,12 @@ class FigureFormatter(object):
             self.single.map_x_axis_label(mapping=mapping)
         return self
 
-    def map_y_axis_labels(self, mapping: Union[Dict[str, str], Callable[[str], str]]) -> 'FigureFormatter':
+    def map_y_axis_labels(
+            self, mapping: Union[Dict[str, str], Callable[[str], str]]
+    ) -> 'FigureFormatter':
         """
-        Map the label text for each y-axis in the Figure using a dictionary or function.
+        Map the label text for each y-axis in the Figure using a dictionary
+        or function.
 
         :param mapping: Dictionary or a function mapping old text to new text.
         """
@@ -178,9 +286,12 @@ class FigureFormatter(object):
             self.single.map_y_axis_label(mapping=mapping)
         return self
 
-    def map_axes_labels(self, mapping: Union[Dict[str, str], Callable[[str], str]]) -> 'FigureFormatter':
+    def map_axes_labels(
+            self, mapping: Union[Dict[str, str], Callable[[str], str]]
+    ) -> 'FigureFormatter':
         """
-        Map the label text for each axis in the Figure using a dictionary or function.
+        Map the label text for each axis in the Figure using a dictionary
+        or function.
 
         :param mapping: Dictionary or a function mapping old text to new text.
         """
@@ -190,7 +301,8 @@ class FigureFormatter(object):
 
     def wrap_axes_titles(self, max_width: int) -> 'FigureFormatter':
         """
-        Wrap the text for each Axes title if it exceeds a given width of characters.
+        Wrap the text for each Axes title if it exceeds a given width
+        of characters.
 
         :param max_width: The maximum character width per line.
         """
@@ -201,14 +313,17 @@ class FigureFormatter(object):
                 axf.wrap_title(max_width=max_width)
         return self
 
-    def save(self, file_path: Union[str, Path], file_type: str = 'png') -> 'FigureFormatter':
+    def save(
+            self, file_path: Union[str, Path], file_type: str = 'png'
+    ) -> 'FigureFormatter':
         """
         Save the plot to disk.
 
         :param file_path: The file path to save the plot object to.
         :param file_type: The type of file to save.
         """
-        save_plot(plot_object=self._figure, file_path=file_path, file_type=file_type)
+        save_plot(plot_object=self._figure,
+                  file_path=file_path, file_type=file_type)
         return self
 
     @staticmethod
